@@ -20,11 +20,11 @@ Template::Flute - Modern designer-friendly HTML templating Engine
 
 =head1 VERSION
 
-Version 0.0162
+Version 0.0170
 
 =cut
 
-our $VERSION = '0.0162';
+our $VERSION = '0.0170';
 
 =head1 SYNOPSIS
 
@@ -199,6 +199,19 @@ Hash reference of filter functions.
 
 L<Template::Flute::I18N> object.
 
+=item translate_attributes
+
+An arrayref of attribute names to translate. If the name has a dot, it
+is interpreted as tagname + attribute, so C<placeholder>" will
+unconditionally translate all the placeholders, while
+C<input.placeholder> only the placeholder found on the input tag.
+
+Additional dotted values compose conditions for attributes. E.g.
+C<input.value.type.submit> means all the value attributes with
+attribute C<type> set to C<submit>.
+
+Defaults to C<['input.value.type.submit', 'placeholder']>
+
 =item iterators
 
 Hash references of iterators.
@@ -295,7 +308,9 @@ sub new {
 	$filter_class = {};
     $filter_objects = {};
     
-	$self = {iterators => {}, @_, 
+	$self = {iterators => {},
+             translate_attributes => [qw/placeholder input.value.type.submit/],
+             @_,
              _filter_subs => $filter_subs,
              _filter_opts => $filter_opts,
              _filter_class => $filter_class,
@@ -475,7 +490,8 @@ sub process {
 	
 	if ($self->{i18n}) {
 		# translate static text first
-		$self->{template}->translate($self->{i18n});
+		$self->{template}->translate($self->{i18n},
+                                     @{$self->{translate_attributes}});
 	}
 
 	my $html = $self->_sub_process(
@@ -573,6 +589,8 @@ sub _sub_process {
 	}	
 
     while (my ($name, $value) = each %iter_names) {
+        next if $name =~ /\./;
+
         if (@$value > 1) {
             my $iter_cached = Template::Flute::Iterator::Cache->new(
                 iterator => $specification->iterator($name),
@@ -713,6 +731,9 @@ sub _sub_process {
 		while (my $record_values = $iter_records->next) {
 
             $count_iterations++;
+            last
+                if defined $list->{limit}
+                && $count_iterations > $list->{limit};
 
             # cut the separators away before copying
             for my $sep (@{$list->{separators}}) {
@@ -1431,7 +1452,7 @@ sub value {
                 }
             }
 
-            if (ref $raw_value) {
+            if (ref $raw_value && ! $self->_is_record_object($raw_value)) {
                 # second case: don't pass back stringified reference
                 $raw_value = '';
             }
@@ -2043,6 +2064,48 @@ Output:
   </html>
 
 
+=head3 Limit lists
+
+Sometimes you may wish to limit the number or iterations through you list.
+
+Specification:
+
+    <specification>
+        <list name="images" iterator="images" limit="1">
+            <param name="image" target="src" field="image_url" />
+        </list>
+    </specification>
+
+Template:
+
+    <div class="images">
+        <img class="image" src="/images/bottle.jpg" />
+    </div>
+
+Code:
+
+    $images = [
+        { image_url => '/images/bottle1.jpg' },
+        { image_url => '/images/bottle2.jpg' },
+        { image_url => '/images/bottle3.jpg' },
+    ];
+
+    $flute = Template::Flute->new(
+        template      => $html,
+        specification => $spec,
+        values        => { images => $images },
+    );
+
+    $out = $flute->process;
+
+Output:
+
+    <html><head></head><body>
+        <div class="images">
+            <img class="image" src="/images/bottle1.jpg" />
+        </div>
+    </body></html>
+
 =head1 LISTS
 
 Lists can be accessed after parsing the specification and the HTML template
@@ -2277,6 +2340,10 @@ L<http://search.cpan.org/dist/Template-Flute/>
 
 =head1 ACKNOWLEDGEMENTS
 
+Thanks to Peter Mottram (GH #81, #87).
+
+Thanks to William Carr (GH #86, #91).
+
 Thanks to David Precious (bigpresh) for writing a much clearer introduction for
 Template::Flute.
 
@@ -2288,7 +2355,7 @@ Template::Flute::Filter::JsonVar class.
 
 Thanks to Ton Verhagen for being a big supporter of my projects in all aspects.
 
-Thanks to Sam Batschelet helping me with a bug causing duplicate form fields (GH #14).
+Thanks to Sam Batschelet (GH #14, #93).
 
 Thanks to Terrence Brannon for spotting a documentation mix-up.
 
